@@ -89,6 +89,7 @@ class OwenProtocol():
                 else:
                     count += 1
                     time.sleep(1)
+                self._logger.warning(f'Connection problems were encountered: {ex}, trying to repeat. Trial #{count}')
         return string
 
     def request_PIC(self, parameter:str) -> float:
@@ -126,6 +127,7 @@ class OwenProtocol():
                 else:
                     count += 1
                     time.sleep(1)
+                self._logger.warning(f'Connection problems were encountered: {ex}, trying to repeat. Trial #{count}')
         return pic
 
     def send_PIC(self, parameter:str, value:float):
@@ -280,6 +282,8 @@ class OwenProtocol():
                 if byte == chr(0x0d):
                     break
             self._logger.debug(f'Got message: {message = }')
+        if len(message) == 0:
+            raise FurnaceProtocolException('Empty message was received from device')
         if message[0] != chr(0x23) or message[-1] != chr(0x0d):
             raise FurnaceProtocolException(f'Unexpected format of message got from device: {message}')
         return message
