@@ -1,3 +1,9 @@
+# gases connected to mass flow controllers
+gases = [
+        'He',
+        'O2',
+        'CO',
+        ]
 # mass flow controllers calibrations
 # see config.py for details
 calibrations = [
@@ -18,6 +24,8 @@ isothermal = 30
 # list of measurement temperatures
 temperatures = []
 # name of sample
-sample_name = 
+sample_name = '
 # operator's name
-operator = 
+operator = '
+# catalyst loading
+sample_mass = 
